import Route from "../route.js";
import initDb from "../db.js";
import { compare } from "bcrypt";
import { randomBytes } from 'node:crypto';
import captcha from "./captcha.js";

let db = await initDb();

let main = new Route([captcha], async function (req, res, input) {
    let { user, pass } = req.body;
    let { captchaMatch } = input;

    if (!captchaMatch) return { 'success': false, 'message': 'Captcha is incorrect' };

    if (!pass || !user) return { 'success': false, 'message': 'Some fields are missing' };

    let isExist = await db.all('SELECT * FROM auth WHERE UPPER(username) LIKE UPPER(?)', [
        user
    ]);

    if (isExist.length < 1) return { 'success': false, 'message': 'Account does not exist' };

    let passHash = await compare(pass, isExist[0].password);

    if (!passHash)
        return { 'success': false, 'message': 'Incorrect password' };

    let token = randomBytes(32).toString('hex');

    await db.run('INSERT INTO token (username, token) VALUES (?, ?)', [
        user,
        token
    ])

    res.cookie('token', token);

    return { 'success': true, 'message': 'Log in succeeded', 'redirect': (req.query.redirect == 'undefined' ? '/' : req.query.redirect) + '?token=' + token, 'data': token };
});

export default main;